==> nofrills_0.1.0.tar.gz: nofrills/tests/testthat/test-quasiquotation.R <==
context("Quasiquotation")

context("fn()")

test_that("default values can be unquoted", {
  zero <- 0
  expect_equal(fn(x = !! zero ~ NULL), function(x = 0) NULL)
  expect_equal(fn(x = UQ(zero) ~ NULL), function(x = 0) NULL)
})

test_that("arguments names can be unquoted", {
  arg <- "x"
  expect_equal(fn(!! arg := 0 ~ NULL), function(x = 0) NULL)
  expect_equal(fn(UQ(arg) := 0 ~ NULL), function(x = 0) NULL)
})

test_that("arguments can be unquoted, as symbols", {
  arg <- as.name("x")
  expect_equal(fn(!! arg ~ NULL), function(x) NULL)
  expect_equal(fn(UQ(arg) ~ NULL), function(x) NULL)
})

test_that("formals can be spliced in as arguments", {
  f <- function(x, y = 1, ..., z = x + y) x + y + z
  fmls <- formals(f)
  expect_equal(fn(!!! fmls, ~ x + y + z), f)
  expect_equal(fn(UQS(fmls), ~ x + y + z), f)
  expect_equal(fn(!!! formals(f), ~ x + y + z), f)
  expect_equal(fn(UQS(formals(f)), ~ x + y + z), f)
})

test_that("function body can be unquoted", {
  f <- function(x) {
    one <- 1
    x + one
  }
  expect_equal(fn(x ~ !! body(f)), f)
  expect_equal(fn(x ~ UQ(body(f))), f)
})

context("as_fn()")

foo <- function(x) as_fn(x)

test_that("default values can be unquoted", {
  zero <- 0
  expect_equal(foo(.(x = !! zero ~ NULL)), function(x = 0) NULL)
  expect_equal(foo(.(x = UQ(zero) ~ NULL)), function(x = 0) NULL)
})

test_that("arguments names can be unquoted", {
  arg <- "x"
  expect_equal(foo(.(!! arg := 0 ~ NULL)), function(x = 0) NULL)
  expect_equal(foo(.(UQ(arg) := 0 ~ NULL)), function(x = 0) NULL)
})

test_that("arguments can be unquoted, as symbols", {
  arg <- as.name("x")
  expect_equal(foo(.(!! arg ~ NULL)), function(x) NULL)
  expect_equal(foo(.(UQ(arg) ~ NULL)), function(x) NULL)
})

test_that("formals can be spliced in as arguments", {
  f <- function(x, y = 1, ..., z = x + y) x + y + z
  fmls <- formals(f)
  expect_equal(foo(.(!!! fmls, ~ x + y + z)), f)
  expect_equal(foo(.(UQS(fmls), ~ x + y + z)), f)
  expect_equal(foo(.(!!! formals(f), ~ x + y + z)), f)
  expect_equal(foo(.(UQS(formals(f)), ~ x + y + z)), f)
})

test_that("function body can be unquoted", {
  f <- function(x) {
    one <- 1
    x + one
  }
  expect_equal(foo(.(x ~ !! body(f))), f)
  expect_equal(foo(.(x ~ UQ(body(f)))), f)
})

==> nofrills_0.2.0.tar.gz: nofrills/tests/testthat/test-quasiquotation.R <==
context("Quasiquotation")

context("fn()")

test_that("default values can be unquoted", {
  zero <- 0
  expect_equal(fn(x = !! zero ~ NULL), function(x = 0) NULL)
  expect_equal(fn(x = UQ(zero) ~ NULL), function(x = 0) NULL)
})

test_that("arguments names can be unquoted", {
  arg <- "x"
  expect_equal(fn(!! arg := 0 ~ NULL), function(x = 0) NULL)
  expect_equal(fn(UQ(arg) := 0 ~ NULL), function(x = 0) NULL)
})

test_that("arguments can be unquoted, as symbols", {
  arg <- as.name("x")
  expect_equal(fn(!! arg ~ NULL), function(x) NULL)
  expect_equal(fn(UQ(arg) ~ NULL), function(x) NULL)
})

test_that("formals can be spliced in as arguments", {
  f <- function(x, y = 1, ..., z = x + y) x + y + z
  fmls <- formals(f)
  expect_equal(fn(!!! fmls, ~ x + y + z), f)
  expect_equal(fn(UQS(fmls), ~ x + y + z), f)
  expect_equal(fn(!!! formals(f), ~ x + y + z), f)
  expect_equal(fn(UQS(formals(f)), ~ x + y + z), f)
})

test_that("function body can be unquoted", {
  f <- function(x) {
    one <- 1
    x + one
  }
  expect_equal(fn(x ~ !! body(f)), f)
  expect_equal(fn(x ~ UQ(body(f))), f)
})

test_that("unquoting operators can be literally expressed", {
  expect_equal(fn(x = foo(QUQ(y)) ~ NULL), function(x = foo(UQ(y))) NULL)
  expect_equal(fn(x = foo(QUQS(y)) ~ NULL), function(x = foo(UQS(y))) NULL)
  expect_equal(fn(x = foo(QUQE(y)) ~ NULL), function(x = foo(UQE(y))) NULL)
  expect_equal(fn(x ~ foo(QUQ(x))), function(x) foo(UQ(x)))
  expect_equal(fn(x ~ foo(QUQS(x))), function(x) foo(UQS(x)))
  expect_equal(fn(x ~ foo(QUQE(x))), function(x) foo(UQE(x)))
})

context("as_fn()")

foo <- function(x) as_fn(x)

test_that("default values can be unquoted", {
  zero <- 0
  expect_equal(foo(.(x = !! zero ~ NULL)), function(x = 0) NULL)
  expect_equal(foo(.(x = UQ(zero) ~ NULL)), function(x = 0) NULL)
})

test_that("arguments names can be unquoted", {
  arg <- "x"
  expect_equal(foo(.(!! arg := 0 ~ NULL)), function(x = 0) NULL)
  expect_equal(foo(.(UQ(arg) := 0 ~ NULL)), function(x = 0) NULL)
})

test_that("arguments can be unquoted, as symbols", {
  arg <- as.name("x")
  expect_equal(foo(.(!! arg ~ NULL)), function(x) NULL)
  expect_equal(foo(.(UQ(arg) ~ NULL)), function(x) NULL)
})

test_that("formals can be spliced in as arguments", {
  f <- function(x, y = 1, ..., z = x + y) x + y + z
  fmls <- formals(f)
  expect_equal(foo(.(!!! fmls, ~ x + y + z)), f)
  expect_equal(foo(.(UQS(fmls), ~ x + y + z)), f)
  expect_equal(foo(.(!!! formals(f), ~ x + y + z)), f)
  expect_equal(foo(.(UQS(formals(f)), ~ x + y + z)), f)
})

test_that("function body can be unquoted", {
  f <- function(x) {
    one <- 1
    x + one
  }
  expect_equal(foo(.(x ~ !! body(f))), f)
  expect_equal(foo(.(x ~ UQ(body(f)))), f)
})
